@@ -161,7 +161,9 @@ void fill_user_stations_list(GSList *source_list, GtkListStore** list){
 	    if(temp2)
 		station_name = g_strdup(temp2);
 #ifdef HILDON		
-	    if(!strcmp(app->gps_station.id0, station_code) &&
+	    if  (app->gps_station.id0 && app->gps_station.name &&
+                station_code && station_name &&
+                !strcmp(app->gps_station.id0, station_code) &&
 		!strcmp(app->gps_station.name, station_name))
 		is_gps = TRUE;
 	    else
@@ -315,7 +317,7 @@ int new_read_config(AppletConfig *config){
 	tmp = NULL;
     }
 #endif    
-
+    
     /* Get Weather Stations ID and NAME */
     stlist = gconf_client_get_list(gconf_client,
         			    GCONF_KEY_WEATHER_STATIONS_LIST,
