@@ -300,7 +300,7 @@ static gboolean form_url_and_filename(gchar *station_code){
         full_filename_new_xml = NULL;
     } 
     url = g_string_new(NULL);        
-    g_string_append_printf(url,"http://xoap.weather.com/weather/local/%s?cc=*&prod=xoap&par=1004517364&key=a29796f587f206b2&unit=m&dayf=%d",
+    g_string_append_printf(url,"http://xoap.weather.com/weather/local/%s?cc=*&prod=xoap&link=xoap&par=1004517364&key=a29796f587f206b2&unit=m&dayf=%d",
 				    station_code, Max_count_weather_day);
     full_filename_new_xml = g_string_new(NULL);        
     g_string_append_printf(full_filename_new_xml,"%s/%s.xml.new",
