@@ -70,6 +70,10 @@ int new_parse_weather_com_xml(void){
     struct tm	*tm = NULL,
 		tmp_tm = {0};
     Item	*itm;
+
+#ifndef RELEASE
+    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#endif
     
 /*Prepare date string */
 /* Imortant need will Check New Year in future !!!!!!!!!!! */
@@ -114,7 +118,6 @@ int new_parse_weather_com_xml(void){
 	    return -1;
 	}    
     }
-
     for(cur_node = parser->weather_com_root->children; cur_node != NULL; cur_node = cur_node->next){
 	if( cur_node->type == XML_ELEMENT_NODE ){
     	    /* Check error */
