@@ -261,9 +261,14 @@ GtkWidget* create_header_widget(GSList *day){
     gchar       buffer[1024];
     struct tm	tmp_time_date_struct = {0};
 
+#ifdef HILDON    
+    GtkIconInfo *gtkicon_update;
+#endif
 /* Show full or short name station */
     location_label = gtk_label_new(app->config->current_station_name);
 /*    set_font_color(location_label, 0x0000, 0x0000, 0x0000);*/
+
+#ifdef HILDON
 /* prepare icon */
     icon = gtk_image_new_from_icon_name("qgn_toolb_gene_refresh",
                                          GTK_ICON_SIZE_INVALID);
@@ -277,6 +282,23 @@ GtkWidget* create_header_widget(GSList *day){
     gtk_widget_set_events(button, GDK_BUTTON_PRESS_MASK);
     g_signal_connect(button, "clicked",
 		    	    G_CALLBACK(pre_update_weather), NULL);
+#else
+    GtkIconInfo *gtkicon_update;
+/* prepare icon */
+    gtkicon_update = gtk_icon_theme_lookup_icon(gtk_icon_theme_get_default(),
+        	                        	"qgn_toolb_gene_refresh", 26, 0);
+    icon = gtk_image_new_from_file(gtk_icon_info_get_filename(gtkicon_update));
+    gtk_icon_info_free(gtkicon_update);
+/* prepare button */    
+    button = gtk_button_new();
+    gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
+    gtk_button_set_focus_on_click(GTK_BUTTON(button), FALSE);
+    gtk_container_add(GTK_CONTAINER(button), icon);
+    gtk_widget_set_events(button, GDK_BUTTON_PRESS_MASK);
+    g_signal_connect(button, "clicked",
+		    	    G_CALLBACK(pre_update_weather), NULL);      
+#endif
+
     /* prepare location and button hbox */
     location_button_hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(location_button_hbox),
