@@ -442,18 +442,40 @@ static gboolean weather_delete_station(GtkWidget *widget, GdkEvent *event,
 		else
 		    gtk_tree_path_free(path);
 	    }
-	    else{/* if no next station than set current station to NO STATION */
-		/* update current station code */
-        	if(app->config->current_station_id)
-            	    g_free(app->config->current_station_id);
-        	app->config->current_station_id = NULL;
-        	/* update current station name */
-        	if(app->config->current_station_name)
-            	    g_free(app->config->current_station_name);
-        	app->config->current_station_name = NULL;
-        	app->config->previos_days_to_show = app->config->days_to_show;
-		gtk_tree_path_free(path);
-		break;
+	    else{/* try to get next station */
+		valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(app->user_stations_list),
+						    &iter, path);
+		if(valid){
+		    /* set current station */
+		    gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
+                        		    &iter,
+                        		    0, &station_name,
+                        		    1, &station_code,
+                        		    -1);
+		    /* update current station code */
+        	    if(app->config->current_station_id)
+            	        g_free(app->config->current_station_id);
+        	    app->config->current_station_id = station_code;
+        	    /* update current station name */
+        	    if(app->config->current_station_name)
+            	        g_free(app->config->current_station_name);
+        	    app->config->current_station_name = station_name;
+        	    app->config->previos_days_to_show = app->config->days_to_show;
+		    break;
+		}
+		else{/* if no next station than set current station to NO STATION */
+		    /* update current station code */
+        	    if(app->config->current_station_id)
+            		g_free(app->config->current_station_id);
+        	    app->config->current_station_id = NULL;
+        	    /* update current station name */
+        	    if(app->config->current_station_name)
+            		g_free(app->config->current_station_name);
+        	    app->config->current_station_name = NULL;
+        	    app->config->previos_days_to_show = app->config->days_to_show;
+		    gtk_tree_path_free(path);
+		    break;
+		}
 	    }
 	}
 	else{
@@ -703,7 +725,9 @@ void weather_window_settings(GtkWidget *widget,	GdkEvent *event,
 		*down_icon = NULL,
 		*up_station_button = NULL,
 		*down_station_button = NULL;
+#ifdef HILDON
     GtkIconInfo *gtkicon_arrow;
+#endif
     gboolean	valid = FALSE;
     GtkTreeIter	iter;
     char	flag_update_icon = '\0'; /* Flag update main weather icon of desktop */
@@ -1515,7 +1539,7 @@ void create_about_dialog(void){
 	      "Russian - Pavel Fialko, Vlad Vasiliev,\n\t    Ed Bartosh\n"
 	      "Finnish - Marko Vertainen\n"
 	      "German - Claudius Henrichs\n"
-	      "Italian - Pavel Fialko\n"));
+	      "Italian - Pavel Fialko, Alessandro Pasotti\n"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			create_scrolled_window_with_text(tmp_buff,
 						    GTK_JUSTIFY_LEFT),
